Crate ravenlang

Crate ravenlang 

Re-exports

pub use epr_check::Cycle;
pub use epr_check::render_cycle;
pub use prop::Prop;

Modules

epr_check
prop

Structs

Axiom
Builder
Use Builder to easily define and compose Raven IR terms.
Call
The details of a symbolic function call.
CaseName
CheckedSig
FunOp
Goal
HypotheticalCall
HypotheticalCallSyntax
IGen
A bit of state used to auto-generate fresh variable names.
InstRule
InstRuleSyntax
MatchArm
NodeApply
NodeSeq
OpCode
PredOp
PredSymbol
RecOp
RirFn
RirFnSig
Sig
SolverConfig
TypeContext

Enums

BType
A BType is a base type, which can be represented directly by a sort.
Binder1
Computations that bind a single variable for use in a body computation.
BinderN
Computations that bind multiple variables for use in a body computation.
CType
Comp
Ident
Identifiers, which may be variable names or function names.
InstMode
Literal
LogOp1
LogOpN
A logical operator that takes zero or more arguments.
Oc
Op
OpMode
Pattern
Quantifier
Rebuild
TypeDef
VType
A VType is a base type or a tuple
Val

Functions

block_to_builder
parse_str_cbpv
parse_str_syn
substruct_code
syn_to_builder

Type Aliases

Cases