Re-exports
pub use epr_check::Cycle;pub use epr_check::render_cycle;pub use prop::Prop;
Modules
Structs
- Axiom
- Builder
- Use
Builderto easily define and compose Raven IR terms. - Call
- The details of a symbolic function call.
- Case
Name - Checked
Sig - FunOp
- Goal
- Hypothetical
Call - Hypothetical
Call Syntax - IGen
- A bit of state used to auto-generate fresh variable names.
- Inst
Rule - Inst
Rule Syntax - Match
Arm - Node
Apply - NodeSeq
- OpCode
- PredOp
- Pred
Symbol - RecOp
- RirFn
- RirFn
Sig - Sig
- Solver
Config - Type
Context
Enums
- BType
- A BType is a base type, which can be represented directly by a sort.
- Binder1
- Computations that bind a single variable for use in a body computation.
- BinderN
- Computations that bind multiple variables for use in a body computation.
- CType
- Comp
- Ident
- Identifiers, which may be variable names or function names.
- Inst
Mode - Literal
- LogOp1
- LogOpN
- A logical operator that takes zero or more arguments.
- Oc
- Op
- OpMode
- Pattern
- Quantifier
- Rebuild
- TypeDef
- VType
- A VType is a base type or a tuple
- Val